@@ -61,8 +61,10 @@ require File.expand_path('../compute', __FILE__)
 require File.expand_path('../dns', __FILE__)
 require File.expand_path('../identity', __FILE__)
 require File.expand_path('../image', __FILE__)
+require File.expand_path('../introspection', __FILE__)
 require File.expand_path('../metering', __FILE__)
 require File.expand_path('../monitoring', __FILE__)
+require File.expand_path('../nfv', __FILE__)
 require File.expand_path('../network', __FILE__)
 require File.expand_path('../orchestration', __FILE__)
 require File.expand_path('../storage', __FILE__)
